==> ToPASeq_1.2.0.tgz: ToPASeq/doc/ToPASeq.R <==
### R code from vignette source 'ToPASeq.Rnw'

###################################################
### code chunk number 1: ToPASeq.Rnw:82-83
###################################################
options(width=60)


###################################################
### code chunk number 2: lib
###################################################
library(ToPASeq)
library(DEGraph)
data(Loi2008_DEGraphVignette)
pathways<-pathways("hsapiens", "kegg")[1:5]
pathways<-lapply(pathways, function(p) as(p,"pathway"))
ls()


###################################################
### code chunk number 3: ToPASeq.Rnw:104-133 (eval = FALSE)
###################################################
## top<-TopologyGSA(exprLoi2008, classLoi2008, pathways, type="MA", nperm=200)
## #99 node labels mapped to the expression data
## #Average coverage 31.47657 %
## #0 (out of 5) pathways without a mapped node
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## #Adrenergic signaling in cardiomyocytes
## #African trypanosomiasis
## res(top)
## #                                        t.value df.mean1 df.mean2 p.value
## #Acute myeloid leukemia                 3080.663       30      224   0.000
## #Adherens junction                      1102.830       10      244   0.040
## #Adipocytokine signaling pathway        3196.432       25      229   0.000
## #Adrenergic signaling in cardiomyocytes 2178.476       26      228   0.055
## #African trypanosomiasis                1400.088        8      246   0.000
## #                                       lambda.value df.var  p.value.var
## #Acute myeloid leukemia                    217.92044    165 3.622794e-03
## #Adherens junction                          39.92094     10 1.749659e-05
## #Adipocytokine signaling pathway           192.81336    121 3.595452e-05
## #Adrenergic signaling in cardiomyocytes    169.47418     80 2.211953e-08
## #African trypanosomiasis                    13.77192     15 5.428926e-01
## #                                       qchisq.value var.equal
## #Acute myeloid leukemia                    195.97336         1
## #Adherens junction                          18.30704         1
## #Adipocytokine signaling pathway           147.67353         1
## #Adrenergic signaling in cardiomyocytes    101.87947         1
## #African trypanosomiasis                    24.99579         0
## 


###################################################
### code chunk number 4: ToPASeq.Rnw:143-145
###################################################
deg<-DEGraph(exprLoi2008, classLoi2008, pathways, type="MA")
res(deg)


###################################################
### code chunk number 5: ToPASeq.Rnw:156-190 (eval = FALSE)
###################################################
## cli<-Clipper( exprLoi2008, classLoi2008, pathways,type="MA", test="mean")
## #99 node labels mapped to the expression data
## #Average coverage 31.47657 %
## #0 (out of 5) pathways without a mapped node
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## #Adrenergic signaling in cardiomyocytes
## #African trypanosomiasis
## res(cli)
## #                                       alphaVar alphaMean  maxScore activation
## #Acute myeloid leukemia                    0.788     0.008  4.336307  0.1255490
## #Adherens junction                         0.087     0.027        NA         NA
## #Adipocytokine signaling pathway           0.675     0.000 33.209403  0.8012589
## #Adrenergic signaling in cardiomyocytes    0.108     0.042        NA         NA
## #African trypanosomiasis                   0.966     0.005        NA         NA
## #                                          impact
## #Acute myeloid leukemia                 0.3846154
## #Adherens junction                             NA
## #Adipocytokine signaling pathway        0.5000000
## #Adrenergic signaling in cardiomyocytes        NA
## #African trypanosomiasis                       NA
## #                                                                                                                                                                                                                                                                                    involvedGenes
## #Acute myeloid leukemia                                                                                                                                                                                                                                              2475;6199;1978;2475;2475;6198
## #Adherens junction                                                                                                                                                                                                                                                                              NA
## #Adipocytokine signaling pathway        32;51422;53632;5562;5563;5564;5565;5571;2538;51422;53632;5562;5563;5564;5565;5571;5105;51422;53632;5562;5563;5564;5565;5571;5106;51422;53632;5562;5563;5564;5565;5571;51422;53632;5562;5563;5564;5565;5571;57818;51422;53632;5562;5563;5564;5565;5571;6517
## #Adrenergic signaling in cardiomyocytes                                                                                                                                                                                                                                                         NA
## #African trypanosomiasis                                                                                                                                                                                                                                                                        NA
## #                                                                                                                                                                                                                                                                                        pathGenes
## #Acute myeloid leukemia                                                                                                                                                     10000;207;208;23533;3265;3845;4893;5290;5291;5293;5294;5295;5296;8503,10000;207;208;2475,2475;6199,1978;2475,2475;6198
## #Adherens junction                                                                                                                                                                                                                                                                              NA
## #Adipocytokine signaling pathway        32;51422;53632;5562;5563;5564;5565;5571,2538;51422;53632;5562;5563;5564;5565;5571,5105;51422;53632;5562;5563;5564;5565;5571,5106;51422;53632;5562;5563;5564;5565;5571,51422;53632;5562;5563;5564;5565;5571;57818,51422;53632;5562;5563;5564;5565;5571;6517
## #Adrenergic signaling in cardiomyocytes                                                                                                                                                                                                                                                         NA
## #African trypanosomiasis                                                                                                                                                                                                                                                                        NA


###################################################
### code chunk number 6: ToPASeq.Rnw:199-201
###################################################
spi<-SPIA(exprLoi2008, classLoi2008,pathways , type="MA", logFC.th=-1)
res(spi)


###################################################
### code chunk number 7: ToPASeq.Rnw:209-211
###################################################
tap<-TAPPA(exprLoi2008, classLoi2008, pathways, type="MA")
res(tap)


###################################################
### code chunk number 8: ToPASeq.Rnw:220-241 (eval = FALSE)
###################################################
## tbs<-TBS( exprLoi2008, classLoi2008, pathways, type="MA",  logFC.th=-1, nperm=100)
## #99 node labels mapped to the expression data
## #Average coverage 31.47657 %
## #0 (out of 5) pathways without a mapped node
## #0 denoted as 0
## # 1 denoted as 1
## # Contrasts:  0 - 1
## #Found 40 differentially expressed genes
## #Preparing permutation table and downstream list
## #Observed scores..
## #Random scores..
## #100
## #Normalization and p-values...
## res(tbs)
## #                                       TBS.obs.norm    p     p.adj
## #Acute myeloid leukemia                   -0.8012546 0.90 0.9000000
## #Adherens junction                         2.9052652 0.03 0.1250000
## #Adipocytokine signaling pathway           0.8461749 0.10 0.1666667
## #Adrenergic signaling in cardiomyocytes   -0.5548923 0.80 0.9000000
## #African trypanosomiasis                   1.5028307 0.05 0.1250000
## 


###################################################
### code chunk number 9: ToPASeq.Rnw:249-271 (eval = FALSE)
###################################################
## pwe<-PWEA(exprLoi2008, classLoi2008, pathways,  type="MA", nperm=100)
## #99 node labels mapped to the expression data
## #Average coverage 31.47657 %
## #0 (out of 5) pathways without a mapped node
## #0 denoted as 0
## # 1 denoted as 1
## # Contrasts:  0 - 1
## #Preparing data..
## #100
## #Processing gene set:
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## #Adrenergic signaling in cardiomyocytes
## #African trypanosomiasis
## res(pwe)
## #                                              ES    p p.adj
## #Acute myeloid leukemia                 0.1995347 0.81  0.81
## #Adherens junction                      0.5757274 0.67  0.81
## #Adipocytokine signaling pathway        0.3272288 0.32  0.81
## #Adrenergic signaling in cardiomyocytes 0.3888446 0.68  0.81
## #African trypanosomiasis                0.3544996 0.46  0.81


###################################################
### code chunk number 10: ToPASeq.Rnw:283-289
###################################################
library(gageData)
data(hnrnp.cnts)
hnrnp.cnts<-hnrnp.cnts[rowSums(hnrnp.cnts)>0,]
group<-c(rep("sample",4), rep("control",4))
pathways<-pathways("hsapiens", "kegg")
pathways<-lapply(pathways, function(p) as(p,"pathway"))


###################################################
### code chunk number 11: ToPASeq.Rnw:300-319 (eval = FALSE)
###################################################
## top<-TopologyGSA(hnrnp.cnts, group, pathways[1:3], type="RNASeq", nperm=1000)
## #528 node labels mapped to the expression data
## #Average coverage 83.16538
## #0 (out of 10) pathways without a mapped node
## #Normalization method was not specified. TMM used as default
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## #Adrenergic signaling in cardiomyocytes
## #African trypanosomiasis
## #Alanine, aspartate and glutamate metabolism
## #Aldosterone-regulated sodium reabsorption
## #Allograft rejection
## #alpha-Linolenic acid metabolism
## 
## res(top)
## #data frame with 0 columns and 1 rows
## 
## 


###################################################
### code chunk number 12: ToPASeq.Rnw:331-333
###################################################
deg<-DEGraph(hnrnp.cnts, group, pathways, type="RNASeq")
res(deg)[[1]][[1]]


###################################################
### code chunk number 13: ToPASeq.Rnw:344-366 (eval = FALSE)
###################################################
## cli<-Clipper(hnrnp.cnts, group, pathways, type="RNASeq", method="mean")
## #530 node labels mapped to the expression data
## #Average coverage 82.98681 %
## #0 (out of 10) pathways without a mapped node
## #1  pathways were filtered out
## #Analysing pathway:
## #
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## #Adrenergic signaling in cardiomyocytes
## #African trypanosomiasis
## #Alanine, aspartate and glutamate metabolism
## #Alcoholism
## #Aldosterone-regulated sodium reabsorption
## #Allograft rejection
## #alpha-Linolenic acid metabolism
## res(cli)$results[[1]][1:2,]
## #                       alphaVar alphaMean mean.q.value var.q.value
## #Acute myeloid leukemia    0.026     0.010        0.016       0.033
## #Adherens junction         0.030     0.009        0.016       0.033
## 


###################################################
### code chunk number 14: ToPASeq.Rnw:375-377
###################################################
spi<-SPIA(hnrnp.cnts, group, pathways, type="RNASeq", logFC.th=-1)
res(spi)


###################################################
### code chunk number 15: ToPASeq.Rnw:385-387
###################################################
tap<-TAPPA(hnrnp.cnts, group, pathways, type="RNASeq")
res(tap)


###################################################
### code chunk number 16: ToPASeq.Rnw:396-419 (eval = FALSE)
###################################################
## tbs<-TBS(hnrnp.cnts, group, pathways, type="RNASeq",  logFC.th=-1, nperm=100)
## #528 node labels mapped to the expression data
## #Average coverage 83.16538
## #0 (out of 10) pathways without a mapped node
## #test was not specified. 'vstlimma' used as default
## #Found 5702 differentially expressed genes
## #Preparing permutation table and downstream list
## #Observed scores..
## #Random scores..
## #100
## #Normalization and p-values...
## res(tbs)
## #                                            TBS.obs.norm    p      p.adj
## #Acute myeloid leukemia                        -1.6325413 0.05 0.06250000
## #Adherens junction                             -3.9416308 0.01 0.01666667
## #Adipocytokine signaling pathway               -3.1989858 0.00 0.00000000
## #Adrenergic signaling in cardiomyocytes       -16.1777366 0.00 0.00000000
## #African trypanosomiasis                       -4.0834773 0.00 0.00000000
## #Alanine, aspartate and glutamate metabolism    0.0137086 0.44 0.48888889
## #Alcoholism                                    -4.1997338 0.00 0.00000000
## #Aldosterone-regulated sodium reabsorption      1.9996012 1.00 1.00000000
## #Allograft rejection                           -3.4004380 0.01 0.01666667
## #alpha-Linolenic acid metabolism               -2.6720346 0.02 0.02857143                                                0.0000000


###################################################
### code chunk number 17: ToPASeq.Rnw:427-456 (eval = FALSE)
###################################################
## pwe<-PWEA(hnrnp.cnts, group, pathways, type="RNASeq", nperm=100)
## #528 node labels mapped to the expression data
## #Average coverage 83.16538
## #0 (out of 10) pathways without a mapped node
## #test was not specified. 'vstlimma' used as default
## #Preparing data..
## #1  2  3  4  5  6  7  8  9  10  11  12  13  14  15  16  17  18  19  20  21  22  23  24  25  26  27  28  29  30  31  32  33  34  35  36  37  38  39  40  41  42  43  44  45  46  47  48  49  50  51  52  53  54  55  56  57  58  59  60  61  62  63  64  65  66  67  68  69  70  71  72  73  74  75  76  77  78  79  80  81  82  83  84  85  86  87  88  89  90  91  92  93  94  95  96  97  98  99  100  Processing gene set:
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## #Adrenergic signaling in cardiomyocytes
## #African trypanosomiasis
## #Alanine, aspartate and glutamate metabolism
## #Alcoholism
## #Aldosterone-regulated sodium reabsorption
## #Allograft rejection
## #alpha-Linolenic acid metabolism
## res(pwe)
## #                                                   ES    p     p.adj
## #Acute myeloid leukemia                      0.3526104 0.29 0.4142857
## #Adherens junction                           0.3829831 1.00 1.0000000
## #Adipocytokine signaling pathway             0.3102945 1.00 1.0000000
## #Adrenergic signaling in cardiomyocytes      0.3611207 0.20 0.3333333
## #African trypanosomiasis                     0.3272899 0.20 0.3333333
## #Alanine, aspartate and glutamate metabolism 0.2720946 0.20 0.3333333
## #Alcoholism                                  0.4708293 0.86 1.0000000
## #Aldosterone-regulated sodium reabsorption   0.3951037 0.20 0.3333333
## #Allograft rejection                         0.9421248 0.03 0.3000000
## #alpha-Linolenic acid metabolism             0.6587026 0.20 0.3333333


###################################################
### code chunk number 18: ToPASeq.Rnw:477-486 (eval = FALSE)
###################################################
## library(gageData)
## data(hnrnp.cnts)
## 
## group<-c(rep("sample",4), rep("control",4))
## hnrnp.cnts<-hnrnp.cnts[rowSums(hnrnp.cnts)>0,]
## cli<-Clipper(hnrnp.cnts, group, pathways[1:2], type="RNASeq", testCliques=TRUE)
## 
## plot(cli,1, kegg)
## 


###################################################
### code chunk number 19: ToPASeq.Rnw:496-504 (eval = FALSE)
###################################################
## library(gageData)
## data(hnrnp.cnts)
## 
## group<-c(rep("sample",4), rep("control",4))
## hnrnp.cnts<-hnrnp.cnts[rowSums(hnrnp.cnts)>0,]
## spi<-SPIA(hnrnp.cnts, group, kegg[45:50], type="RNASeq", logFC.th=-1)
## plot(spi,"Complement and coagulation cascades", kegg[45:50], fontsize=50)
##

==> ToPASeq_1.4.0.tgz: ToPASeq/doc/ToPASeq.R <==
### R code from vignette source 'ToPASeq.Rnw'

###################################################
### code chunk number 1: ToPASeq.Rnw:66-70
###################################################
library(ToPASeq)
pathways<-pathways("hsapiens", "kegg")[1:5]
pathways[[1]]
str(pathways[[1]])


###################################################
### code chunk number 2: ToPASeq.Rnw:120-121
###################################################
options(width=60)


###################################################
### code chunk number 3: lib
###################################################
library(ToPASeq)
library(DEGraph)
data(Loi2008_DEGraphVignette)
pathways<-pathways("hsapiens", "kegg")[1:5]
ls()


###################################################
### code chunk number 4: ToPASeq.Rnw:142-174 (eval = FALSE)
###################################################
## top<-TopologyGSA(exprLoi2008, classLoi2008, pathways, type="MA", perms=200)
## #99 node labels mapped to the expression data
## #Average coverage 31.47657 %
## #0 (out of 5) pathways without a mapped node
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## #Adrenergic signaling in cardiomyocytes
## #African trypanosomiasis
## res(top)
## #$results
## #                                        t.value df.mean1 df.mean2 p.value
## #Acute myeloid leukemia                 3024.796       30      224       0
## #Adherens junction                      1102.830       10      244       0
## #Adipocytokine signaling pathway        3196.432       25      229       0
## #Adrenergic signaling in cardiomyocytes 2178.476       26      228       0
## #African trypanosomiasis                1404.259        8      246       0
## #                                      lambda.value df.var  p.value.var
## #Acute myeloid leukemia                    213.01437    156 1.649509e-03
## #Adherens junction                          39.92094     10 1.749659e-05
## #Adipocytokine signaling pathway           192.81336    121 3.595452e-05
## #Adrenergic signaling in cardiomyocytes    169.47418     80 2.211953e-08
## #African trypanosomiasis                    13.02808     12 3.670031e-01
## #                                       qchisq.value var.equal q.value
## #Acute myeloid leukemia                    186.14575         1       0
## #Adherens junction                          18.30704         1       0
## #Adipocytokine signaling pathway           147.67353         1       0
## #Adrenergic signaling in cardiomyocytes    101.87947         1       0
## #African trypanosomiasis                    21.02607         0       0
## #
## #$errors
## #named list()


###################################################
### code chunk number 5: ToPASeq.Rnw:184-186
###################################################
deg<-DEGraph(exprLoi2008, classLoi2008, pathways, type="MA")
res(deg)


###################################################
### code chunk number 6: ToPASeq.Rnw:197-226 (eval = FALSE)
###################################################
## cli<-clipper( exprLoi2008, classLoi2008, pathways,type="MA", method="mean")
## #99 node labels mapped to the expression data
## #Average coverage 31.47657 %
## #0 (out of 5) pathways without a mapped node
## #0  pathways were filtered out
## #Analysing pathway:
## #
## #Acute myeloid leukemia 
## #Adherens junction 
## #Adipocytokine signaling pathway 
## #Adrenergic signaling in cardiomyocytes 
## #African trypanosomiasis 
## #0 denoted as 0 
## # 1 denoted as 1
## # Contrasts:  1 - 0 
## #Warning messages:
## #1: In getJunctionTreePaths(graph, root) :
## #  The DAG presents cliques that are not connected.
## #2: In prunePaths(clipped, pruneLevel) : pathSummary is NULL
## #3: In getJunctionTreePaths(graph, root) :
## #  The DAG presents cliques that are not connected.
## #4: In prunePaths(clipped, pruneLevel) : pathSummary is NULL
## res(cli)$results[[1]]
## #                                       alphaVar alphaMean mean.q.value var.q.value
## #Acute myeloid leukemia                    0.735     0.009       0.0150     0.91875
## #Adherens junction                         0.101     0.022       0.0275     0.26500
## #Adipocytokine signaling pathway           0.656     0.001       0.0050     0.91875
## #Adrenergic signaling in cardiomyocytes    0.106     0.061       0.0610     0.26500
## #African trypanosomiasis                   0.953     0.007       0.0150     0.95300


###################################################
### code chunk number 7: ToPASeq.Rnw:237-239
###################################################
spi<-SPIA(exprLoi2008, classLoi2008,pathways , type="MA", logFC.th=-1)
res(spi)


###################################################
### code chunk number 8: ToPASeq.Rnw:254-256
###################################################
tap<-TAPPA(exprLoi2008, classLoi2008, pathways, type="MA")
res(tap)


###################################################
### code chunk number 9: ToPASeq.Rnw:265-268
###################################################
Prs<-PRS( exprLoi2008, classLoi2008, pathways, type="MA",  logFC.th=-1, nperm=100)
res(Prs)



###################################################
### code chunk number 10: ToPASeq.Rnw:284-304 (eval = FALSE)
###################################################
## pwe<-PWEA(exprLoi2008, classLoi2008, pathways,  type="MA", nperm=100)
## #0 denoted as 0 
## # 1 denoted as 1
## # Contrasts:  1 - 0 
## #29 node labels mapped to the expression data
## #Average coverage 5.752782 %
## #1 (out of 5) pathways without a mapped node
## #1  pathways were filtered out
## # Preparing permutations..
## res(pwe)
## #$results
## #                                               ES p.value   q.value
## #Acute myeloid leukemia                 -0.1516072    0.36 0.5066667
## #Adherens junction                       0.2576037    1.00 1.0000000
## #Adipocytokine signaling pathway         0.2221782    0.38 0.5066667
## #Adrenergic signaling in cardiomyocytes -0.2265755    0.05 0.2000000
## #
## #$errors
## #named list()
## 


###################################################
### code chunk number 11: seq1
###################################################
library(gageData)
data(hnrnp.cnts)
hnrnp.cnts<-hnrnp.cnts[rowSums(hnrnp.cnts)>0,]
group<-c(rep("sample",4), rep("control",4))
pathways<-pathways("hsapiens", "kegg")



###################################################
### code chunk number 12: seq2 (eval = FALSE)
###################################################
## top<-TopologyGSA(hnrnp.cnts, group, pathways[1:3], type="RNASeq", nperm=1000)
## #528 node labels mapped to the expression data
## #Average coverage 83.16538
## #0 (out of 10) pathways without a mapped node
## #Normalization method was not specified. TMM used as default
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## 
## 
## res(top)
## #data frame with 0 columns and 1 rows
## 
## 


###################################################
### code chunk number 13: seq3
###################################################
deg<-DEGraph(hnrnp.cnts, group, pathways, type="RNASeq")
res(deg)[[1]][[1]]


###################################################
### code chunk number 14: seq4 (eval = FALSE)
###################################################
## cli<-clipper(hnrnp.cnts, group, pathways, type="RNASeq", method="mean")
## #530 node labels mapped to the expression data
## #Average coverage 82.98681 %
## #0 (out of 10) pathways without a mapped node
## #1  pathways were filtered out
## #Analysing pathway:
## #
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## #Adrenergic signaling in cardiomyocytes
## #African trypanosomiasis
## #Alanine, aspartate and glutamate metabolism
## #Alcoholism
## #Aldosterone-regulated sodium reabsorption
## #Allograft rejection
## #alpha-Linolenic acid metabolism
## res(cli)$results[[1]][1:2,]
## #                       alphaVar alphaMean mean.q.value var.q.value
## #Acute myeloid leukemia    0.026     0.010        0.016       0.033
## #Adherens junction         0.030     0.009        0.016       0.033
## 


###################################################
### code chunk number 15: seq5
###################################################
spi<-SPIA(hnrnp.cnts, group, pathways, type="RNASeq", logFC.th=-1)
res(spi)


###################################################
### code chunk number 16: seq6
###################################################
tap<-TAPPA(hnrnp.cnts, group, pathways, type="RNASeq")
res(tap)


###################################################
### code chunk number 17: seq7
###################################################
Prs<-PRS(hnrnp.cnts, group, pathways, type="RNASeq",  logFC.th=-1, nperm=100)
res(Prs)


###################################################
### code chunk number 18: seq8 (eval = FALSE)
###################################################
## pwe<-PWEA(hnrnp.cnts, group, pathways, type="RNASeq", nperm=100)
## #528 node labels mapped to the expression data
## #Average coverage 83.16538
## #0 (out of 10) pathways without a mapped node
## #Acute myeloid leukemia
## #Adherens junction
## #Adipocytokine signaling pathway
## #Adrenergic signaling in cardiomyocytes
## #African trypanosomiasis
## #Alanine, aspartate and glutamate metabolism
## #Alcoholism
## #Aldosterone-regulated sodium reabsorption
## #Allograft rejection
## #alpha-Linolenic acid metabolism
## res(pwe)
## #                                                   ES    p     p.adj
## #Acute myeloid leukemia                      0.3526104 0.29 0.4142857
## #Adherens junction                           0.3829831 1.00 1.0000000
## #Adipocytokine signaling pathway             0.3102945 1.00 1.0000000
## #Adrenergic signaling in cardiomyocytes      0.3611207 0.20 0.3333333
## #African trypanosomiasis                     0.3272899 0.20 0.3333333
## #Alanine, aspartate and glutamate metabolism 0.2720946 0.20 0.3333333
## #Alcoholism                                  0.4708293 0.86 1.0000000
## #Aldosterone-regulated sodium reabsorption   0.3951037 0.20 0.3333333
## #Allograft rejection                         0.9421248 0.03 0.3000000
## #alpha-Linolenic acid metabolism             0.6587026 0.20 0.3333333


###################################################
### code chunk number 19: plot1 (eval = FALSE)
###################################################
## #Fails during check
## library(gageData)
## data(hnrnp.cnts)
## 
## group<-c(rep("sample",4), rep("control",4))
## hnrnp.cnts<-hnrnp.cnts[rowSums(hnrnp.cnts)>0,]
## res<-clipper(hnrnp.cnts, group, pathways[1:2], type="RNASeq", testCliques=TRUE)
## 
## plot(res,1, pathways)
## 


###################################################
### code chunk number 20: plot2 (eval = FALSE)
###################################################
## library(gageData)
## data(hnrnp.cnts)
## 
## group<-c(rep("sample",4), rep("control",4))
## hnrnp.cnts<-hnrnp.cnts[rowSums(hnrnp.cnts)>0,]
## pathways<-pathways("hsapiens", "kegg")[50:55]
## spi<-SPIA(hnrnp.cnts, group, pathways, type="RNASeq", logFC.th=-1)
## plot(spi,"Complement and coagulation cascades", pathways, fontsize=50)
##
